<?php

namespace Drupal\chatbase\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Chatbase settings for this site.
 */
class ChatbaseSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'chatbase_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['chatbase.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('chatbase.settings');

    $form['secret_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Secret Key'),
      '#default_value' => $config->get('secret_key'),
      '#required' => TRUE,
    ];
    $form['chatbot_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Chatbot ID'),
      '#default_value' => $config->get('chatbot_id'),
      '#required' => TRUE,
    ];

    $form['chatbot_embed'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('ChatBot embed'),
    ];
    $form['chatbot_embed']['chatbot_enabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable ChatBot'),
      '#description' => $this->t('Add a chat bubble to the bottom of your website.'),
      '#default_value' => $config->get('chatbot_enabled'),
    ];
    $form['chatbot_embed']['chatbot_exclude_admin_theme'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Exclude from Admin theme'),
      '#default_value' => $config->get('chatbot_exclude_admin_theme'),
      '#states' => [
        'visible' => [
          ':input[name="chatbot_enabled"]' => ['checked' => TRUE],
        ],
      ],
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('chatbase.settings')
      ->set('secret_key', $form_state->getValue('secret_key'))
      ->set('chatbot_id', $form_state->getValue('chatbot_id'))
      ->set('chatbot_enabled', $form_state->getValue('chatbot_enabled'))
      ->set('chatbot_exclude_admin_theme', $form_state->getValue('chatbot_exclude_admin_theme'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
